changeset 18303:d4e516050f24 draft

(svn r23139) -Change: [NewGRF v8] Do no longer apply base cost fallbacks.
author frosch <frosch@openttd.org>
date Tue, 08 Nov 2011 17:24:01 +0000
parents 4925b06e241f
children b84b00f90388
files src/newgrf.cpp
diffstat 1 files changed, 2 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/src/newgrf.cpp
+++ b/src/newgrf.cpp
@@ -8682,9 +8682,10 @@
 		}
 	}
 
 	/* Apply fallback prices */
 	const GRFFile * const *end = _grf_files.End();
 	for (GRFFile **file = _grf_files.Begin(); file != end; file++) {
+		if ((*file)->grf_version >= 8) continue;
 		PriceMultipliers &price_base_multipliers = (*file)->price_base_multipliers;
 		for (Price p = PR_BEGIN; p < PR_END; p++) {
 			Price fallback_price = _price_base_specs[p].fallback_price;
@@ -8682,9 +8682,10 @@
 	}
 
-	/* Apply fallback prices */
+	/* Apply fallback prices for grf version < 8 */
 	const GRFFile * const *end = _grf_files.End();
 	for (GRFFile **file = _grf_files.Begin(); file != end; file++) {